Skip to contents

Reads the readme for name and returns its source, vintage, licence, caveats, and contact information.

Usage

layer_meta(name, print = TRUE, ...)

Arguments

name

Character; layer name or catalogue id as listed by list_layers().

print

Logical; if TRUE (default), print a formatted summary to the console.

...

Passed to list_layers(), e.g. root or refresh.

Value

A sciSpatial_metadata list, invisibly.

See also

read_metadata() to parse a readme by path, get_layer() to load the data the metadata describes.

Examples

if (FALSE) { # \dontrun{
layer_meta("fab_dem")
md <- layer_meta("fab_dem", print = FALSE)
md$use_constraints
} # }