Skip to contents

Shows the columns that identify the gap and truncates the list of missing fields, matching the manifest printer. name is dropped as a prefix of id.

Usage

# S3 method for class 'sciSpatial_audit'
print(x, ...)

Arguments

x

A sciSpatial_audit object.

...

Ignored.

Value

x, invisibly.