Drops examples, which is too long to tabulate, and truncates
the description, matching the manifest printer.
Usage
# S3 method for class 'sciSpatial_themes'
print(x, ...)Drops examples, which is too long to tabulate, and truncates
the description, matching the manifest printer.
# S3 method for class 'sciSpatial_themes'
print(x, ...)