Extracts cell values from x at each location in points.
Points are reprojected to the raster CRS if needed (a warning is
issued when this happens). The returned data.frame has the
same number of rows as points with one additional column per
raster layer.
Arguments
- x
A
SpatRasterwith one or more layers.- points
An
sforSpatVectorof point locations.- bind
Logical; if
TRUE(default), the extracted values are column-bound to the attributes ofpoints. IfFALSE, only the extracted values are returned.- ...
Additional arguments passed to
terra::extract().